import fastapi
from fastapi.security import OAuth2PasswordRequestForm

from schemas import CreateUserSchema, CreatedUserResponseSchema, RefreshTokenSchema, AccessTokenSchema
from ctrl import UserController
import services


user_router = fastapi.APIRouter(prefix='/users')
auth_router = fastapi.APIRouter(prefix='/auth')
ctrl = UserController()


@user_router.post('')
async def create_users(
        body: CreateUserSchema
) -> CreatedUserResponseSchema:
    return await ctrl.create(**body.model_dump(exclude_none=True))


@auth_router.post('/login')
async def login(
    form_data: OAuth2PasswordRequestForm = fastapi.Depends(),
):
    return await services.auth_service.login(form_data)


@auth_router.post('/check_token')
async def check_token(
    data: AccessTokenSchema,
):
    response = await services.auth_service.check_token(data.token)
    return response


@auth_router.post('/refresh')
async def refresh_token(
    data: RefreshTokenSchema,
):
    return services.token_service.refresh_token(data.refresh_token)
