from uuid import UUID

from db.repositories import ChapterRepository
from .schemas import ChapterSchema


class ChapterService:
    chapter_repository = ChapterRepository()

    async def get_chapter_list(self, **kwargs):
        chapters = await self.chapter_repository.get_list(**kwargs)
        return [ChapterSchema.model_validate(chapter) for chapter in chapters]

    async def get_chapter(self, id: UUID):
        chapter = await self.chapter_repository.get(id)
        return ChapterSchema.model_validate(chapter)

    async def create_chapter(self, **kwargs):
        chapter = await self.chapter_repository.create(**kwargs)
        return ChapterSchema.model_validate(chapter)

    async def update_chapter(self, id: UUID, **kwargs):
        chapter = await self.chapter_repository.update(id, **kwargs)
        return ChapterSchema.model_validate(chapter)

    async def delete_chapter(self, id: UUID):
        return await self.chapter_repository.delete(id)
