import httpx
import fastapi as fa


async def get_current_user(token: str):
    auth_service_url = "http://auth:8000/api/auth/check_token"

    async with httpx.AsyncClient() as client:
        data = {"token": token}
        response = await client.post(auth_service_url, json=data)

        if response.status_code == 200:
            result = response.json()
            if result.get("success"):
                return result
            else:
                raise fa.HTTPException(
                    status_code=401,
                    detail="Unauthorized: Invalid token",
                )
        else:
            raise fa.HTTPException(
                status_code=fa.status.HTTP_400_BAD_REQUEST,
                detail="Error while fetching user data",
            )
